@@ -4,12 +4,13 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use base qw/Import::Export/;
 
 our %EX = (
-        const => [qw/all/]
+        const => [qw/all/],
+	make_readonly => [qw/all/]
 );
 
 require XSLoader;
@@ -25,7 +26,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
@@ -34,7 +35,7 @@ Version 0.09
 
 	package MyApp::Constants;
 
-	use Const::XS qw/all/;
+	use Const::XS qw/const/;
 	
 	use base 'Import::Export';
 
@@ -64,7 +65,7 @@ Version 0.09
 
 =head2 const
 
-This is the only function of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
+This is the one of two functions of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
 
 	const my %factory => (
 		workers => 5,
@@ -77,6 +78,25 @@ This is the only function of this module. It takes a scalar, array or hash lvalu
 	$factory{not_set}; # errors
 	exists $factory{not_set}; # false
 
+=head2 make_readonly
+
+The second function exported by this module is make_readonly. It will take a perl variable or reference and make it readonly. 
+
+	my $string = "abc";
+	make_readonly($string);
+	$string = 'def'; # errors
+
+	my $ref = { a => 1, b => 2, c => 3 };
+	make_readonly($ref);
+	$ref->{d}; # errors
+	$ref = { new => 1 }; # errors 
+
+Please note that if you call make_readonly on struct directly it will make that struct readonly however it is 'copied' into the variable and that does not get set as readonly. Take the following example.
+
+	my $ref = make_readonly({a => 1, b => 2, c => 3 }; # we copy into $ref
+	$ref->{d}; # errors
+	$ref = { new => 1 };  # is okay
+
 =head2 BENCHMARK
 
 	use Benchmark qw(:all);
